<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+273"/>
        <source>None</source>
        <translatorcomment>--exact match--
--file: qt_fr.ts--
Aucun
Aucune des expressions pragma n&apos;est supportée. Une expression par défault doit être présente</translatorcomment>
        <translation>Aucun</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Pouce
Micropouce</translatorcomment>
        <translation>Pouce</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Pied</translatorcomment>
        <translation>Pied</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Mile</translatorcomment>
        <translation>Mile</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Millimètre
Millimètres (mm)</translatorcomment>
        <translation>Millimètre</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Centimètre
Centimètres (cm)</translatorcomment>
        <translation>Centimètre</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Permuter le signe de diamètre
Diamètre</translatorcomment>
        <translation>Mètre</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Kilomètre</translatorcomment>
        <translation>Kilomètre</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Micropouce</translatorcomment>
        <translation>Micropouce</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Tamoul
Mile</translatorcomment>
        <translation>Mil</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Yard</translatorcomment>
        <translation>Yard</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Angström</translatorcomment>
        <translation>Angström</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Nanomètre</translatorcomment>
        <translation>Nanomètre</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Micron</translatorcomment>
        <translation>Micron</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Décimètre</translatorcomment>
        <translation>Décimètre</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Décamètre</translatorcomment>
        <translation>Décamètre</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Hectomètre</translatorcomment>
        <translation>Hectomètre</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Gigamètre</translatorcomment>
        <translation>Gigamètre</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Astro</translatorcomment>
        <translation>Astro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Année-lumière</translatorcomment>
        <translation>Année-lumière</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translatorcomment>--exact match--
--file: UnitSettings_fr.ts--
Parsec</translatorcomment>
        <translation>Parsec</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+288"/>
        <source>By Layer</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Par calque</translatorcomment>
        <translation>Par calque</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Par bloc</translatorcomment>
        <translation>Par bloc</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translatorcomment>--exact match--
--file: designer_fr.ts--
&amp;Rétablir
Rétablir
Rétablit la dernière action</translatorcomment>
        <translation>Rouge</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Yellow</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Jaune</translatorcomment>
        <translation>Jaune</translation>
    </message>
    <message>
        <location line="-4"/>
        <source>Green</source>
        <translatorcomment>--exact match--
--file: designer_fr.ts--
Vert
Greenphone (179 x 185)</translatorcomment>
        <translation>Vert</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Cyan</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Cyan</translatorcomment>
        <translation>Cyan</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Blue</source>
        <translatorcomment>--exact match--
--file: designer_fr.ts--
Bleu
Bleu&#xa0;: 
Bluetooth</translatorcomment>
        <translation>Bleu</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Magenta</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Magenta</translatorcomment>
        <translation>Magenta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Orange</source>
        <translation>Orange</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation>Rouge foncé</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation>Vert foncé</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation>Bleu foncé</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation>Cyan foncé</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation>Magenta foncé</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation>Jaune foncé</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translatorcomment>--exact match--
--file: qt_fr.ts--
Noir/Blanc
Extra-gras</translatorcomment>
        <translation>Noir</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>White</source>
        <translatorcomment>--exact match--
--file: FirstStart_fr.ts--
Noir/Blanc
Blanc</translatorcomment>
        <translation>Blanc</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Gray</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Gris
Gris clair</translatorcomment>
        <translation>Gris</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Gris clair</translatorcomment>
        <translation>Gris clair</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Others...</source>
        <translatorcomment>--exact match--
--file: Text_fr.ts--
Autres...</translatorcomment>
        <translation>Autres...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+45"/>
        <source>Current Layer ID</source>
        <translation>ID du calque actuel</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation>Unité de mesure du dessin</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Échelle du type de la ligne</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation>Police pour les cotations</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+92"/>
        <source>Block</source>
        <translatorcomment>--exact match--
--file: Block_fr.ts--
&amp;Bloc
Bloc
Liste des blocs</translatorcomment>
        <translation>Bloc</translation>
    </message>
    <message>
        <source>Referenced Block</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Bloc référencé</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+66"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+1"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+82"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+72"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+73"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translatorcomment>--exact match--
--file: designer_fr.ts--
Sortie de l&apos;application...
Sortie de l&apos;application
Exportation du dessin...</translatorcomment>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-3"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: qt_fr.ts--
Indiquer la position de la ligne de cote ou un angle :
Indiquer la position de la ligne de cote ou un angle
Indiquer la position [angle/longueur]</translatorcomment>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-1"/>
        <source>Pixel Unit</source>
        <translation>Pixel unité</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Origine</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-1"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-1"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translatorcomment>--exact match--
--file: designer_fr.ts--
&amp;Modifier
Modifier
&amp;Calque</translatorcomment>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translatorcomment>--google--
Partage &amp;Horizontal
Partage Horizontal
&amp;Horizontale</translatorcomment>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation>Présentation</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
        <source>Scale</source>
        <translatorcomment>--exact match--
--file: Scale_fr.ts--
&amp;Echelle
Echelle
Met les entités à l&apos;échelle</translatorcomment>
        <translation>Échelle</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translatorcomment>--exact match--
--file: designer_fr.ts--
Angle :
Angle
Indiquer l&apos;angle de la ligne de cote :</translatorcomment>
        <translation>Angle</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translation>Colonnes</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translation>Lignes</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translation>Espacement des colonnes</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translation>Espacement des lignes</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation>Attributs</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+91"/>
        <location filename="../src/core/RObject.cpp" line="+67"/>
        <source>Type</source>
        <translatorcomment>--exact match--
--file: qt_fr.ts--
Type de trait :
Type de trait
Type ordonnée</translatorcomment>
        <translation>Type</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Block ID</source>
        <translation>Bloc ID</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layer</source>
        <translatorcomment>--exact match--
--file: AdvancedSelection_fr.ts--
&amp;Calque
Liste des calques</translatorcomment>
        <translation>Calque</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+102"/>
        <source>Linetype</source>
        <translatorcomment>--exact match--
--file: LinetypeSettings_fr.ts--
Type de ligne par défaut
Type de ligne</translatorcomment>
        <translation>Type de ligne</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Échelle du type de ligne</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Épaisseur de ligne</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translatorcomment>--exact match--
--file: qt_fr.ts--
Couleurs
Ouvrir la boîte de dialogue des couleurs</translatorcomment>
        <translation>Couleur</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation>Couleur affichée</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ordre de dessin</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation>Limite</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation>En bas</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation>En haut</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+151"/>
        <source>Custom</source>
        <translation>Personnalisé</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation>Poignée</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation>Protégé</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Selected</source>
        <translation>Sélectionné</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+2"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation>Largeur</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location line="+0"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation>Hauteur</translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation>Simple</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Position du texte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation>Texte brut</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation>Nom de police</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation>Hauteur du texte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation>Angle du texte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation>Echelle X</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation>Gras</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation>Italique</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation>Espacement lignes</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation>Alignement</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation>Rotation</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation>Activé</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation>Affichage centre</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translation>Affichage cible</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translation>Overall</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-6"/>
        <location filename="../src/core/RLayer.cpp" line="-8"/>
        <location filename="../src/core/RLayerState.cpp" line="+46"/>
        <location filename="../src/core/RLayout.cpp" line="-24"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Caché</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Off</source>
        <translation>Inactif</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation>Gelés</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation>Verrouillée</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation>Plié</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation>Traçable</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation>Accrochable</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translation>Éteint est gelé</translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Tab Order</source>
        <translation>Ordre de tabulation</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation>Min limites</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation>Max limites</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation>Base insertion</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation>Min extents</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation>Max extents</translation>
    </message>
    <message>
        <source>Plot Margins</source>
        <translation type="vanished">Marges des tracés</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+655"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation>Une référence de bloc circulaire (récursive) a été détectée :</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation>Nom du bloc :</translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+186"/>
        <source>Requires selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Demande une sélection</translation>
    </message>
</context>
<context>
    <name>RLayer</name>
    <message>
        <source>Name</source>
        <translation type="vanished">Nom</translation>
    </message>
    <message>
        <source>Frozen</source>
        <translation type="vanished">Gelé</translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation type="vanished">Caché</translation>
    </message>
    <message>
        <source>Locked</source>
        <translation type="vanished">Verrouillée</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Couleur</translation>
    </message>
    <message>
        <source>Linetype</source>
        <translation type="vanished">Type de ligne</translation>
    </message>
    <message>
        <source>Lineweight</source>
        <translation type="vanished">Épaisseur de ligne</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <source>By Layer</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Par calque</translatorcomment>
        <translation type="vanished">Par calque</translation>
    </message>
    <message>
        <source>By Block</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Par bloc</translatorcomment>
        <translation type="vanished">Par bloc</translation>
    </message>
    <message>
        <source>Continuous</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Continu</translatorcomment>
        <translation type="vanished">Continu</translation>
    </message>
    <message>
        <source>Dot</source>
        <translatorcomment>--exact match--
--file: Input_fr.ts--
Points de la g&amp;rille :
Points de la g&amp;rille
Points de la grille :</translatorcomment>
        <translation type="vanished">Point</translation>
    </message>
    <message>
        <source>Dot (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Point (petit)
Tiret-point (petit)</translatorcomment>
        <translation type="vanished">Point (petit)</translation>
    </message>
    <message>
        <source>Dot (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Point (grand)
Tiret-point (grand)</translatorcomment>
        <translation type="vanished">Point (grand)</translation>
    </message>
    <message>
        <source>Dash</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Tiret
Tiret (petit)</translatorcomment>
        <translation type="vanished">Tiret</translation>
    </message>
    <message>
        <source>Dash (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Tiret (petit)</translatorcomment>
        <translation type="vanished">Tiret (petit)</translation>
    </message>
    <message>
        <source>Dash (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Tiret (grand)</translatorcomment>
        <translation type="vanished">Tiret (grand)</translation>
    </message>
    <message>
        <source>Dash Dot</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Tiret-point
Tiret-point (petit)</translatorcomment>
        <translation type="vanished">Tiret-point</translation>
    </message>
    <message>
        <source>Dash Dot (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Tiret-point (petit)</translatorcomment>
        <translation type="vanished">Tiret-point (petit)</translation>
    </message>
    <message>
        <source>Dash Dot (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Tiret-point (grand)</translatorcomment>
        <translation type="vanished">Tiret-point (grand)</translation>
    </message>
    <message>
        <source>Divide</source>
        <translatorcomment>--exact match--
--file: Divide_fr.ts--
&amp;Division
Division
Divise les entités</translatorcomment>
        <translation type="vanished">Division</translation>
    </message>
    <message>
        <source>Divide (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Division (petite)</translatorcomment>
        <translation type="vanished">Division (petite)</translation>
    </message>
    <message>
        <source>Divide (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Division (grande)</translatorcomment>
        <translation type="vanished">Division (grande)</translation>
    </message>
    <message>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: qt_fr.ts--
&amp;Centre, point, angles
Centre, point, angles
Indiquer le centre</translatorcomment>
        <translation type="vanished">Centré</translation>
    </message>
    <message>
        <source>Center (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Centre (petit)</translatorcomment>
        <translation type="vanished">Centre (petit)</translation>
    </message>
    <message>
        <source>Center (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Centre (grand)</translatorcomment>
        <translation type="vanished">Centre (grand)</translation>
    </message>
    <message>
        <source>Border</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Bordure
Bordure (petite)</translatorcomment>
        <translation type="vanished">Bordure</translation>
    </message>
    <message>
        <source>Border (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Bordure (petite)</translatorcomment>
        <translation type="vanished">Bordure (petite)</translation>
    </message>
    <message>
        <source>Border (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Bordure (grande)</translatorcomment>
        <translation type="vanished">Bordure (grande)</translation>
    </message>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+48"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>Métrique</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Motif</translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+856"/>
        <source>By Layer</source>
        <translation>Par calque</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Par bloc</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation>Continu</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation>Bordure</translation>
    </message>
    <message>
        <source>Border (2x)</source>
        <translation type="vanished">Bordure (2x)</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Centre</translation>
    </message>
    <message>
        <source>Center (2x)</source>
        <translation type="vanished">Centre (2x)</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation>Tiret point</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation>Interrompu</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation>Divisé</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation>Pointillé</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Caché</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation>Fantôme</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation>ISO interrompu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation>ISO tiret espace</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation>ISO tiret long point</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation>ISO tiret long deux points</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation>ISO tiret long trois points</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation>ISO pointillé</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation>ISO tiret long tiret court</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation>ISO tiret long deux tirets courts</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation>ISO tiret point</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation>ISO deux tirets point</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation>ISO tiret deux points</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation>ISO deux tirets deux points</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation>ISO tiret trois points</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation>ISO deux tirets trois points</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation>Eau chaude</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation>Eau chaude</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation>Gaz</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation>Isolation</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation>Zig zag</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation>Rails</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation>Ligne-cercles</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation>Ligne-carrés</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drainage</source>
        <translation>Drainage</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translation>Drainage inverse</translation>
    </message>
    <message>
        <source>Drainage Reverse</source>
        <translation type="vanished">Drainage inverse</translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+35"/>
        <source>By Layer</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Par calque</translatorcomment>
        <translation>Par calque</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
Par bloc</translatorcomment>
        <translation>Par bloc</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translatorcomment>--exact match--
--file: qt_fr.ts--
Unité par défaut :
Unité par défaut
Valeurs par &amp;défaut</translatorcomment>
        <translation>Défaut</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
0.00mm</translatorcomment>
        <translation>0.00mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
0.05mm</translatorcomment>
        <translation>0.05mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
0.09mm</translatorcomment>
        <translation>0.09mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
0.13mm (ISO)</translatorcomment>
        <translation>0.13mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
0.15mm</translatorcomment>
        <translation>0.15mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
0.18mm (ISO)</translatorcomment>
        <translation>0.18mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
0.20mm</translatorcomment>
        <translation>0.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
0.25mm (ISO)</translatorcomment>
        <translation>0.25mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
0.30mm</translatorcomment>
        <translation>0.30mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
0.35mm (ISO)</translatorcomment>
        <translation>0.35mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
0.40mm</translatorcomment>
        <translation>0.40mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
0.50mm (ISO)</translatorcomment>
        <translation>0.50mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
0.53mm</translatorcomment>
        <translation>0.53mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
0.60mm</translatorcomment>
        <translation>0.60mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
0.70mm (ISO)</translatorcomment>
        <translation>0.70mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
0.80mm</translatorcomment>
        <translation>0.80mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
0.90mm</translatorcomment>
        <translation>0.90mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
1.00mm (ISO)</translatorcomment>
        <translation>1.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
1.06mm</translatorcomment>
        <translation>1.06mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
1.20mm</translatorcomment>
        <translation>1.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
1.40mm (ISO)</translatorcomment>
        <translation>1.40mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
1.58mm</translatorcomment>
        <translation>1.58mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
2.00mm (ISO)</translatorcomment>
        <translation>2.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_fr.ts--
1.58mm {2.11m?}</translatorcomment>
        <translation>1.58mm {2.11m?}</translation>
    </message>
</context>
<context>
    <name>RObject</name>
    <message>
        <source>Custom</source>
        <translatorcomment>--exact match--
--file: qt_fr.ts--
Aucun objets de dimension sélectionné avec une position de texte personnalisé.
Aucun objets de dimension sélectionné avec une position de texte personnalisé
Personnalisé</translatorcomment>
        <translation type="vanished">Personnalisé</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="vanished">Type</translation>
    </message>
    <message>
        <source>Handle</source>
        <translatorcomment>--google--
Séquence ambiguë %1 non traitée
Poignée du slider</translatorcomment>
        <translation type="vanished">Poignée</translation>
    </message>
    <message>
        <source>Protected</source>
        <translation type="vanished">Protégé</translation>
    </message>
</context>
</TS>
